/* -------------------------------------------------------
 *   Profiler.es
 *  Author:    G. Wade Johnson
 *  Created:   10/12/2008
 *  Copyright 2008 G. Wade Johnson
 *  Available for any use if this notice is maintained.
 *
 * Crude profiling tool for ECMAscript and SVG.
 * Keeps a count of trigger points and reports it's findings to an element.
 */

function setText(elem, str)
{
    var text = document.createTextNode( str );
    elem.replaceChild( text, elem.firstChild );
}

// Here's our class for tracking the speed of the program
function Profiler( label, sample_rate )
{
    this.label = label;
    this.rate = sample_rate*1000; // Turn seconds into ms.
    this.start = new Date().getTime();
    this.prev_time = this.start;

    this.count = 0;
    this.summary_count = 0;
    this.prev_count = 0;
    this.avg = 0;
    this.inter_avg = 0;

    this.reset = function() {
        this.start = new Date().getTime();
        this.count = 0;
        this.avg = 0;
        this.prev_time = this.start;
        this.prev_count = 0;
        this.inter_avg = 0;
        this.summary_count = 0;
    }
    this.trigger = function() {
        this.count++;
    };
    this.update_label = function() {
        if( null == this.elem )
        {
            this.elem = document.getElementById( this.label );
            if( null == this.elem )
            {
                return;
            }
        }
//        setText( this.elem, this.avg );
//        setText( this.elem, this.inter_avg );
        setText( this.elem, this.summary_count+": "+this.avg+" ("+this.inter_avg+" inst)" );
    };
    this.summary = function() {
        var curr = new Date().getTime();
        var elapsed = (curr - this.start) / this.rate;
        this.avg = (new Number(this.count / elapsed)).toFixed( 2 );

        elapsed = (curr - this.prev_time) / this.rate;
        this.inter_avg = (new Number( (this.count-this.prev_count) / elapsed)).toFixed( 2 );

        this.prev_count = this.count;
        this.prev_time = curr;
        this.summary_count++;

        this.update_label();
    };
}

