/* -------------------------------------------------------
 *   ProfilerLogger.es
 *  Author:    G. Wade Johnson
 *  Created:   10/13/2008
 *  Copyright 2008 G. Wade Johnson
 *  Available for any use if this notice is maintained.
 *
 * Crude profiling tool for ECMAscript and SVG.
 * Keeps a count of trigger points and reports it's findings to an element.
 */

function setText(elem, str)
{
    var text = document.createTextNode( str );
    elem.replaceChild( text, elem.firstChild );
}

// Here's our class for tracking the speed of the program
function Profiler( label, sample_rate, marker )
{
    this.label = label;
    this.rate = sample_rate*1000; // Turn seconds into ms.
    this.marker = marker;
    this.start = new Date().getTime();
    this.prev_time = this.start;

    this.count = 0;
    this.prev_count = 0;
    this.avg = 0;
    this.inst_avg = 0;
    this.log_count = 0;

    this.trigger = function() {
        this.count++;
    };
    this.update_label = function() {
        if( null == this.elem )
        {
            this.elem = document.getElementById( this.label );
            if( null == this.elem )
            {
                return;
            }
        }
        setText( this.elem, this.log_count+": "+this.tot_avg+" ("+this.avg+" inst)" );
        this.logit();
    };
    this.summary = function() {
        var curr = new Date().getTime();
        this.tot_elapsed = (curr - this.start) / this.rate;
        this.tot_avg = (new Number(this.count / this.tot_elapsed)).toFixed( 2 );

        this.elapsed = (curr - this.prev_time) / this.rate;
        this.avg = (new Number( (this.count-this.prev_count) / this.elapsed)).toFixed( 2 );

        this.prev_count = this.count;
        this.prev_time = curr;

        this.log_count++;
        this.update_label();
    };
    this.logit = function() {
        var url = 'logit.html?count='+this.log_count
                +'&avg='+this.avg
                +'&tot_avg='+this.tot_avg
                +'&tot_elapsed='+this.tot_elapsed
                +'&elapsed='+this.elapsed
                +'&tot_count='+this.prev_count
                +'&marker='+this.marker;
        this.get_request( url );
    }
    if(window.getURL)
    {
        this.get_request = function(url) {
            getURL( url, function() {} );
        };
    }
    else if(window.XMLHttpRequest)
    {
        this.get_request = function(url) {
            var req = new XMLHttpRequest();
            req.open( 'GET', url, true );
            req.send( '' );
        };
    }
    else
    {
        alert( "I don't kow how to make an HTTP request." );
        this.get_request = function(url) {};
    }
    this.begin = function(secs) {
        this.interval = secs*1000;
        this.count = 0;
        this.avg = 0;
        this.prev_time = this.start;
        this.prev_count = 0;
        this.inst_avg = 0;
        this.log_count = 0;
        if(this.sampler)
        {
            clearInterval( this.sampler );
        }
        this.start = new Date().getTime();
        var prof = this;
        this.sampler = setInterval( function() { prof.summary(); }, this.interval );
    }
    this.stop = function() {
        if(this.sampler)
        {
            clearInterval( this.sampler );
        }
    }
}

